@@ -110,8 +110,7 @@ gridSearch <- function(model,
   if (!is.null(env)) {
     # TODO: Remove with version 2.0.0
     if (inherits(env, "Raster")) {
-      .warn_raster("raster", "rast")
-      env <- terra::rast(env)
+      .raster_error("rast")
     }
 
     if (!inherits(env, "SpatRaster"))
