@@ -18,12 +18,10 @@
 #' @param clamp logical for clumping during prediction, used for response curves
 #' and for the prediction map.
 #' @param permut integer. Number of permutations.
-#' @param factors deprecated, package \pkg{terra} handles factors in a different
-#' way than \pkg{raster}, see \pkg{terra} documentation.
 #' @param verbose logical, if `TRUE` prints informative messages.
 #'
 #' @details The function produces a report similar to the one created by MaxEnt
-#' software.
+#' software. See \pkg{terra} documentation to see how to pass factors.
 #'
 #' @export
 #'
@@ -86,7 +84,6 @@ modelReport <- function(model,
                         env = NULL,
                         clamp = TRUE,
                         permut = 10,
-                        factors = NULL,
                         verbose = TRUE) {
 
   if (!requireNamespace("kableExtra", quietly = TRUE)) {
@@ -103,13 +100,6 @@ modelReport <- function(model,
     )
   }
 
-  # TODO: remove with version 2.0.0
-  if (!is.null(factors))
-    cli::cli_abort(c(
-      "!" = "Argument {.var factors} is deprecated",
-      "x" = "Please check {.pkg terra} documentation to see how to use factors."
-    ))
-
   if (file.exists(file.path(getwd(), folder))) {
     msg <- cli::cli_text(cli::col_red(cli::symbol$fancy_question_mark),
                          " The folder {.file {folder}} already exists,",
@@ -154,7 +144,6 @@ modelReport <- function(model,
                                     only_presence = only_presence,
                                     clamp = clamp,
                                     permut = permut,
-                                    factors = factors,
                                     verbose = verbose),
                       quiet = TRUE
                       )
