@@ -12,7 +12,6 @@
 #' must include the extension.
 #' @param overwrite logical. If `TRUE` an existing file is overwritten.
 #' @param wopt list. Writing options passed to \link[terra]{writeRaster}.
-#' @param format character. Deprecated.
 #' @param ... Unused arguments.
 #'
 #' @return A \link[ggplot2]{ggplot} object.
@@ -53,7 +52,6 @@ plotPA <- function(map,
                    filename = "",
                    overwrite = FALSE,
                    wopt = list(),
-                   format = "",
                    ...) {
 
   if (!requireNamespace("rasterVis", quietly = TRUE)) {
@@ -65,8 +63,7 @@ plotPA <- function(map,
 
   # TODO: Remove with version 2.0.0
   if (inherits(map, "RasterLayer")) {
-    .warn_raster("raster", "rast")
-    map <- terra::rast(map)
+    .raster_error("rast")
   }
 
   if (!inherits(map, "SpatRaster"))
@@ -75,14 +72,6 @@ plotPA <- function(map,
       "x" = "You have supplied a {.cls {class(map)}} instead."
     ))
 
-  # TODO: Remove with version 2.0.0
-  if (format != "")
-    cli::cli_warn(c(
-      "!" = paste("The argument {.val format} is deprectated and will be",
-                  "ignored. Use {.val wopt} instead and see {.val Details} in",
-                  "{.fun terra::writeRaster}")
-    ))
-
   pa <- map >= th
 
   if (filename != "") {
