@@ -45,8 +45,7 @@ plotPred <- function(map,
 
   # TODO: Remove with version 2.0.0
   if (inherits(map, "RasterLayer")) {
-    .warn_raster("raster", "rast")
-    map <- terra::rast(map)
+    .raster_error("rast")
   }
 
   if (!inherits(map, "SpatRaster"))
