@@ -313,10 +313,10 @@
 }
 
 # TODO: Remove with version 2.0.0
-.warn_raster <- function(x, y) {
-  cli::cli_warn(
-    c("!" = "{.cls {x}} objects will not be accepted in future releases",
+.raster_error <- function(x) {
+  cli::cli_abort(
+    c("!" = "Objects from the {.pkg raster} package are no longer supported!",
       "i" = paste("{.pkg SDMtune} now uses {.pkg terra} to handle spatial",
-                  "data. See function {.fun terra::{y}} to migrate."))
+                  "data. See function {.fun terra::{x}} to migrate."))
   )
 }
